-- entry file, creates initial GUI, prepares second screen for launch

-- load up some initial values
function love.load()
	
	-- initial difficulty
	dx = 2
	
	-- initial sound choice
	da = 1
   
    isPlaying = false
    
    -- load media such as sound and images
   	click = love.audio.newSource("media/audio/click.ogg")   
	HAL = love.graphics.newImage("media/HAL9000.png")
	
	-- prepare the second screen so we can launch it later
	funcs = require("maingame")
	funcs.load()
	
	-- initial value of "difficulty" variable
	sc_DIFF = 0
	
end	

-- draw function
function love.draw()

	-- as soon as the second screen is launched, this variable becomes true and we switch
	-- to drawing the second screen instead of this one
	if isPlaying then
		maingamedraw()
		return	
	end
	
	-- setting up the graphics of the intro screen
    love.graphics.setBackgroundColor(245/1.5, 241/1.5, 222/1.5, 255)

	-- draw some boxes
 	love.graphics.rectangle("line", 150, 250, 500, 300)    
 	love.graphics.rectangle("line", 250, 270, 300, 100)    
 	love.graphics.rectangle("line", 250, 370, 300, 100)    
	
	-- more graphics, nothing complicated. we have three main GUI elements: difficulty
	-- setting, audio on/off, and a "Play" button
    local f = love.graphics.newFont(30)
    love.graphics.setFont(f)

	love.graphics.draw(HAL, 285, 10)

    love.graphics.print("Difficulty", 325, 275)

    love.graphics.print("-1", 325, 325)  
    love.graphics.print("0", 375, 325)  
    love.graphics.print("1", 425, 325) 

    -- this rectangle will act as our highlight; its x position varies depending on
    -- difficulty chosen
 	love.graphics.rectangle("line", 275 - 10 + 50 * dx, 325 - 5, 40, 40)    
 	
    love.graphics.print("Audio", 350, 375)  

    love.graphics.print("On", 340, 425)  
    love.graphics.print("Off", 410, 425)  
    
    -- another rectangle with varying x position, this is the audio option
 	love.graphics.rectangle("line", 260 + 75 * da, 425 - 5, 50, 40)   
 	
    love.graphics.print("Play", 370, 495)  
 	love.graphics.rectangle("line", 350, 490, 100, 50)    

end

-- catch mouse input and change the x location of the rectangles that serves as highlights
function love.mousepressed(x, y, button)

   if button == "l" then
   	-- difficulty
      if y > 300 and y < 370 then
      
			if x > 300 and  x < 350 then
				love.audio.play(click)
      			dx = 1
      		elseif x > 300 and  x < 400 then
				love.audio.play(click)
      			dx = 2
      		elseif x > 300 and  x < 450 then
				love.audio.play(click)
      			dx = 3
      		end
      	-- based on the choice here a global value changes
      	sc_DIFF = dx - 2

		-- audio
      	elseif y > 400 and y < 470 then
      	
      		if x > 300 and  x < 400 then
				love.audio.play(click)
				love.audio.setVolume(1)
      			da = 1
			elseif x > 300 and  x < 500 then
				da = 2
				love.audio.setVolume(0)
      		end
      		
      	-- play
		elseif y > 300 and y < 550 then
			if x > 350 and  x < 450 then

			-- upon pressing within the range of the play "button" we bring the second
			-- screen to the front, calling functions that set up its constants and loads
			-- the tetris playing field. we also flip the isPlaying boolen so we cease
			-- drawing elements in this GUI
			
			gameIsPaused = false
			funcs.load()
			setupBoard()
			isPlaying = true
			
			end
        end
    end
    
    -- this mouse button event handler will work regardless of which screen is on top,
    -- for this reason we manually send it to the second screen's handler if isPlaying is
    -- true
    if isPlaying then
		lovemousepressed(x, y, button)
	end
	
end
				
-- update function, runs after every frame
function love.update(dt)
   
   	-- again, the update function runs regardless of which screen we're on, so we manually
   	-- send it to run the second update method
	if isPlaying then
		loveupdate(dt)
	end		
	
end